(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[    206519,       4505]
NotebookOptionsPosition[    206946,       4496]
NotebookOutlinePosition[    207411,       4516]
CellTagsIndexPosition[    207368,       4513]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Introduction to Free Body Diagram\n",
 StyleBox["Zhelong He, Qingchang Liu, Marek-Jerzy Pindera \nUniversity of \
Virginia, 2017-09-25",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
Successful application of the equations of equilibrium requires a complete \
specification of all the known and unknown external forces that act on the \
body. The best way to account for these forces is to draw a free-body \
diagram. This diagram is a sketch of the outlined shape of the body, which \
represents it as being isolated or \[OpenCurlyDoubleQuote]free\
\[CloseCurlyDoubleQuote] from its surroundings, i.e., a \
\[OpenCurlyDoubleQuote]free body.\[CloseCurlyDoubleQuote] On this sketch it \
is necessary to show all the forces and couple moments that the surroundings \
exert on the body so that these effects can be accounted for when the \
equations of equilibrium are applied.
\[FilledCircle] If a support prevents the translation of a body in a given \
direction, then a force is developed on the body in that direction.           \
                                                                              \
                         \[FilledCircle] If rotation is prevented, a couple \
moment is exerted on the body.

Meanwhile, if the equilibrium is broken, the body will begin its movement. In \
the following example, we first show the supporting forces at hinge and \
roller in the equilibrium state. Then, we replace the roller with a \
supporting force, the magnitude of which is changeable thus may not necessary \
makes the beam in equilibrium. We can see that as the supporting force is \
changing, the beam will lose its equilibrium. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`Cy$$ = 1., $CellContext`Lp$$ = 
    2, $CellContext`mg$$ = 2, $CellContext`opa0$$ = 0, $CellContext`opa1$$ = 
    0, $CellContext`rep$$ = 0, $CellContext`time$$ = 
    0., $CellContext`\[Theta]d$$ = 90, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa0$$], 0, 
       Row[{
         Text[
          Style["Coordinates Visibility", 12]], 
         Spacer[48]}]}, {1 -> Text[
         Style["On ", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`Lp$$], 2, 
       Row[{
         Text[
          Style["Position of Loading", 12]], 
         Spacer[43]}]}, 0, 4}, {{
       Hold[$CellContext`mg$$], 2, 
       Row[{
         Text[
          Style["Magnitude of Loading", 12]], 
         Spacer[29]}]}, 0, 4}, {{
       Hold[$CellContext`\[Theta]d$$], 90, 
       Row[{
         Text[
          Style["Direction of Force", 12]], 
         Spacer[50]}]}, 0, 180}, {{
       Hold[$CellContext`opa1$$], 0, 
       Row[{
         Text[
          Style["Reactive Force at Equilibrium", 12]]}]}, {1 -> Text[
         Style["On ", 12]], 0 -> Text[
         Style["Off", 12]]}}, {{
       Hold[$CellContext`rep$$], 0, 
       Row[{
         Text[
          Style["Remove Roller", 12]], 
         Spacer[77]}]}, {1 -> Text[
         Style["Yes", 12]], 0 -> Text[
         Style["No", 12]]}}, {{
       Hold[$CellContext`Cy$$], 1., 
       Row[{
         Text[
          Style["Change Supporting Force", 12]], 
         Spacer[11]}]}, 0, 4}, {{
       Hold[$CellContext`time$$], 0, 
       Row[{
         Text[
          Style["Show Rotation", 12]]}]}, 0, 10}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Manipulate`Place[5]}, {
          PaneSelector[{0 -> Manipulate`Place[6], 1 -> Row[{
               Text[
                Style[
                 Subscript[$CellContext`A, $CellContext`x], 12]], 
               Spacer[3], 
               Text[
                Style["=", 12]], 
               Spacer[3], 
               Text[
                Style[
                 Dynamic[
                  NumberForm[$CellContext`Ax, {3, 2}]], 12, Italic]], 
               Spacer[20], 
               Text[
                Style[
                 Subscript[$CellContext`A, $CellContext`y], 12]], 
               Spacer[3], 
               Text[
                Style["=", 12]], 
               Spacer[3], 
               Text[
                Style[
                 Dynamic[
                  NumberForm[$CellContext`Ay, {3, 2}]], 12, Italic]], 
               Spacer[20], 
               Text[
                Style[
                 Subscript[$CellContext`B, $CellContext`y], 12]], Null, 
               Spacer[3], 
               Text[
                Style["=", 12]], 
               Spacer[3], 
               Text[
                Style[
                 Dynamic[
                  NumberForm[$CellContext`By, {3, 2}]], 12, Italic]]}]}, 
           Dynamic[$CellContext`opa1$$]]}, {
          PaneSelector[{1 -> Column[{
               Manipulate`Place[7], 
               Manipulate`Place[8], 
               Row[{
                 Text[
                  Style["M", 12, Italic]], 
                 Spacer[3], 
                 Text[
                  Style["=", 12, Italic]], 
                 Spacer[3], 
                 Text[
                  Style[
                   Dynamic[
                    NumberForm[$CellContext`moment, {3, 2}]], 12, Italic]]}]},
               Left, Spacings -> {Automatic, 1.5}]}, 
           Dynamic[$CellContext`rep$$]]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {420., {206., 214.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`opa0$1871$$ = False, $CellContext`Lp$1872$$ = 
    0, $CellContext`mg$1873$$ = 0, $CellContext`\[Theta]d$1874$$ = 
    0, $CellContext`opa1$1875$$ = False, $CellContext`rep$1876$$ = 
    False, $CellContext`Cy$1877$$ = 0, $CellContext`time$1878$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`Cy$$ = 1., $CellContext`Lp$$ = 
        2, $CellContext`mg$$ = 2, $CellContext`opa0$$ = 
        0, $CellContext`opa1$$ = 0, $CellContext`rep$$ = 
        0, $CellContext`time$$ = 0, $CellContext`\[Theta]d$$ = 90}, 
      "ControllerVariables" :> {
        Hold[$CellContext`opa0$$, $CellContext`opa0$1871$$, False], 
        Hold[$CellContext`Lp$$, $CellContext`Lp$1872$$, 0], 
        Hold[$CellContext`mg$$, $CellContext`mg$1873$$, 0], 
        Hold[$CellContext`\[Theta]d$$, $CellContext`\[Theta]d$1874$$, 0], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$1875$$, False], 
        Hold[$CellContext`rep$$, $CellContext`rep$1876$$, False], 
        Hold[$CellContext`Cy$$, $CellContext`Cy$1877$$, 0], 
        Hold[$CellContext`time$$, $CellContext`time$1878$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`L$, $CellContext`W$, \
$CellContext`pta$, $CellContext`ptb$, $CellContext`ptc$, $CellContext`ptd$, \
$CellContext`pte$, $CellContext`ptf$, $CellContext`r1$, $CellContext`r2$, \
$CellContext`pca$, $CellContext`pcb$, $CellContext`pcc$, $CellContext`pcd$, \
$CellContext`pce$, $CellContext`dwf0$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$, $CellContext`dwf4$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dw1$, $CellContext`sol$, $CellContext`fe$, $CellContext`fi$, \
$CellContext`\[Theta]$}, $CellContext`\[Theta]$ = ($CellContext`\[Theta]d$$/
           180) Pi; $CellContext`size$ = 5; $CellContext`L$ = 
         4; $CellContext`W$ = 0.1 $CellContext`L$; $CellContext`m = 
         3; $CellContext`ts = 0; $CellContext`te = 
         20; $CellContext`r1$ = $CellContext`W$/
          5; $CellContext`r2$ = $CellContext`W$/4; $CellContext`pta$ = {0, 
          0}; $CellContext`ptb$ = $CellContext`pta$ - {$CellContext`W$/
           1.6, $CellContext`W$/
           1}; $CellContext`ptc$ = $CellContext`ptb$ + {(2/
             1.6) $CellContext`W$, 
            0}; $CellContext`ptd$ = $CellContext`ptb$ + {(-$CellContext`W$)/5,
             0}; $CellContext`pte$ = $CellContext`ptc$ + {$CellContext`W$/5, 
            0}; $CellContext`ptf$ = {
          0, (-$CellContext`W$)/
           2}; $CellContext`pca$ = {$CellContext`L$, (-$CellContext`W$)/
            2 - $CellContext`r2$}; $CellContext`pcb$ = $CellContext`pca$ - {
          0, $CellContext`r2$} - {$CellContext`W$/1.6, 
           0}; $CellContext`pcc$ = $CellContext`pca$ - {
          0, $CellContext`r2$} + {$CellContext`W$/1.6, 
            0}; $CellContext`pcd$ = {$CellContext`L$, 
           0}; $CellContext`pce$ = {$CellContext`L$, (-$CellContext`W$)/
           2}; $CellContext`fe$ = {$CellContext`Lp$$, 
           0}; $CellContext`fi$ = $CellContext`fe$ + {$CellContext`mg$$ 
            Cos[$CellContext`\[Theta]$], $CellContext`mg$$ 
            Sin[$CellContext`\[Theta]$]}; $CellContext`sol$ = Quiet[
           Part[
            Solve[
             
             N[{$CellContext`mg$$ 
                Sin[$CellContext`\[Theta]$] == $CellContext`ay + \
$CellContext`by, $CellContext`mg$$ 
                Cos[$CellContext`\[Theta]$] == $CellContext`ax, \
$CellContext`by == ($CellContext`mg$$ 
                 
                 Sin[$CellContext`\[Theta]$]) \
($CellContext`Lp$$/$CellContext`L$)}], {$CellContext`ax, $CellContext`ay, \
$CellContext`by}], 1]]; $CellContext`Ax = 
         ReplaceAll[$CellContext`ax, $CellContext`sol$]; $CellContext`Ay = 
         ReplaceAll[$CellContext`ay, $CellContext`sol$]; $CellContext`By = 
         ReplaceAll[$CellContext`by, $CellContext`sol$]; $CellContext`moment = \
$CellContext`Cy$$ $CellContext`L$ - ($CellContext`mg$$ 
           Sin[$CellContext`\[Theta]$]) $CellContext`Lp$$; $CellContext`rot = 
         NDSolveValue[{(((1/3) $CellContext`m) $CellContext`L$^2) D[
               $CellContext`\[Alpha][$CellContext`t], {$CellContext`t, 
                2}] == $CellContext`moment, $CellContext`\[Alpha][0] == 0, 
            Derivative[1][$CellContext`\[Alpha]][0] == 
            0}, $CellContext`\[Alpha], {$CellContext`t, $CellContext`ts, \
$CellContext`te}]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa0$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {$CellContext`size$, 0}}], 
           Arrow[{{0, -$CellContext`size$}, {0, $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.95 $CellContext`size$, (-0.1) $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.1) $CellContext`size$, 
             0.95 $CellContext`size$}]}; $CellContext`dwf1$ = Rotate[{
            Opacity[0.5], Blue, 
            
            Rectangle[{
             0, (-0.5) $CellContext`W$}, {$CellContext`L$, 
              0.5 $CellContext`W$}]}, 
           $CellContext`rot[$CellContext`t], {0, 0}]; $CellContext`dwf2$ = {
           Opacity[1 - $CellContext`opa1$$], 
           Thickness[0.005], Black, 
           PointSize[0.02], 
           Point[$CellContext`pta$], 
           Darker[Green], 
           
           Triangle[{$CellContext`pta$, $CellContext`ptb$, \
$CellContext`ptc$}], 
           Thickness[0.012], 
           Circle[$CellContext`pta$, $CellContext`r1$], 
           Thickness[0.005], 
           Line[{$CellContext`ptd$, $CellContext`pte$}], 
           Line[
            Table[{{(-0.3) Sin[Pi/6] + $CellContext`k - 0.1, 
               Part[$CellContext`ptc$, 2]}, {(-0.3) Sin[Pi/6] - 0.1 
               Cos[Pi/3] + $CellContext`k - 0.1, Part[$CellContext`ptc$, 2] - 
               0.1 Sin[Pi/3]}}, {$CellContext`k, 0, 0.5, 
              0.1}]]}; $CellContext`dwf3$ = {
           Opacity[(1 - $CellContext`opa1$$) (1 - $CellContext`rep$$)], 
           Darker[Green], 
           Thickness[0.012], 
           Circle[$CellContext`pca$, $CellContext`r2$], 
           Thickness[0.005], 
           Line[{$CellContext`pcc$, $CellContext`pcb$}], 
           Line[
            Table[{{$CellContext`L$ - 0.3 Sin[Pi/6] + $CellContext`k - 0.1, 
               Part[$CellContext`ptc$, 2]}, {$CellContext`L$ - 0.3 Sin[Pi/6] - 
               0.1 Cos[Pi/3] + $CellContext`k - 0.1, 
               Part[$CellContext`ptc$, 2] - 0.1 Sin[Pi/3]}}, {$CellContext`k, 
              0, 0.5, 0.1}]]}; $CellContext`dwf4$ = Rotate[{
            Thickness[0.005], 
            Arrowheads[0.05], 
            Arrow[{$CellContext`fi$, $CellContext`fe$}], 
            If[Norm[$CellContext`fe$ - $CellContext`fi$] > 0, 
             Text[
              Style[
              "F", Italic, 
               12], $CellContext`fi$ + {0, 0.1} $CellContext`size$]], Dashed, 
            Thickness[0.002], 
            Line[{{0, 0}, {$CellContext`L$, 0}}], 
            PointSize[0.01], 
            Point[$CellContext`fe$]}, 
           $CellContext`rot[$CellContext`t], {0, 0}]; $CellContext`dwf5$ = {
           Opacity[$CellContext`opa1$$], 
           Thickness[0.005], Red, 
           Arrowheads[0.05], 
           If[$CellContext`Ax != 0, 
            If[$CellContext`Ax > 0, 
             
             Arrow[{$CellContext`pta$ - {$CellContext`Ax, 
                0}, $CellContext`pta$}], 
             If[$CellContext`Ax < -0.3, 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + {$CellContext`Ax, 
                  0} + {-0.2, 0}}], 
              
              Arrow[{$CellContext`pta$, $CellContext`pta$ + {$CellContext`Ax, 
                  0}}]]]], 
           If[$CellContext`Ax != 0, 
            Text[
             Style[
              Subscript["A", "x"], 12, Italic], -{
                Norm[$CellContext`Ax], 0} - {1.5 $CellContext`W$, 0}]], 
           If[$CellContext`Ay != 0, {
             
             Arrow[{$CellContext`ptf$ - {
               0, $CellContext`Ay}, $CellContext`ptf$}], 
             Text[
              $CellContext`var2["A", "y"], $CellContext`ptf$ - {
              0, $CellContext`Ay} - {0, 1.5 $CellContext`W$}]}], 
           If[$CellContext`By != 0, {
             
             Arrow[{$CellContext`pce$ - {
               0, $CellContext`By}, $CellContext`pce$}], 
             Text[
              $CellContext`var2["B", "y"], $CellContext`pce$ - {
              0, $CellContext`By} - {
              0, 1.5 $CellContext`W$}]}]}; $CellContext`dwf6$ = Rotate[{
            Opacity[$CellContext`rep$$], 
            Thickness[0.01], Red, 
            Arrowheads[0.05], 
            If[$CellContext`Cy$$ != 0, {
              
              Arrow[{$CellContext`pce$ - {
                0, $CellContext`Cy$$}, $CellContext`pce$}], 
              Text[
               $CellContext`var4["R"], $CellContext`pce$ - {
               0, $CellContext`Cy$$} - {0, 1.5 $CellContext`W$}]}]}, 
           $CellContext`rot[$CellContext`t], {0, 0}]; $CellContext`dwf7$ = {
           Opacity[Boole[$CellContext`moment != 0] $CellContext`rep$$], Blue, 
           Thickness[0.007], 
           Arrowheads[0.03], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/Part[#, 5]}]]& , {{{0, 
               0}, 0.3, Pi - (($CellContext`moment + 10^(-6))/16) Pi, 
               Pi + (($CellContext`moment + 10^(-6))/16) Pi, 100}}]], 
           Text[
           "\!\(\*\nStyleBox[\"M\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {0, 1.5 $CellContext`W$}]}; $CellContext`dw1$ = 
         Graphics[{
            Evaluate[
             
             ReplaceAll[{$CellContext`dwf1$, $CellContext`dwf4$, \
$CellContext`dwf6$}, {$CellContext`t -> $CellContext`time$$}]], \
$CellContext`dwf0$, $CellContext`dwf2$, $CellContext`dwf5$, \
$CellContext`dwf3$, $CellContext`dwf7$}, PlotRange -> $CellContext`size$, 
           ImageSize -> 280, Frame -> False]; $CellContext`dw1$], 
      "Specifications" :> {{{$CellContext`opa0$$, 0, 
          Row[{
            Text[
             Style["Coordinates Visibility", 12]], 
            Spacer[48]}]}, {1 -> Text[
            Style["On ", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         1}, {{$CellContext`Lp$$, 2, 
          Row[{
            Text[
             Style["Position of Loading", 12]], 
            Spacer[43]}]}, 0, 4, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 2}, {{$CellContext`mg$$, 2, 
          Row[{
            Text[
             Style["Magnitude of Loading", 12]], 
            Spacer[29]}]}, 0, 4, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{$CellContext`\[Theta]d$$, 90, 
          Row[{
            Text[
             Style["Direction of Force", 12]], 
            Spacer[50]}]}, 0, 180, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`opa1$$, 0, 
          Row[{
            Text[
             Style["Reactive Force at Equilibrium", 12]]}]}, {1 -> Text[
            Style["On ", 12]], 0 -> Text[
            Style["Off", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         5}, {{$CellContext`rep$$, 0, 
          Row[{
            Text[
             Style["Remove Roller", 12]], 
            Spacer[77]}]}, {1 -> Text[
            Style["Yes", 12]], 0 -> Text[
            Style["No", 12]]}, ControlType -> RadioButton, ControlPlacement -> 
         6}, {{$CellContext`Cy$$, 1., 
          Row[{
            Text[
             Style["Change Supporting Force", 12]], 
            Spacer[11]}]}, 0, 4, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`time$$, 0, 
          Row[{
            Text[
             Style["Show Rotation", 12]]}]}, 0, 10, ImageSize -> Tiny, 
         ControlType -> Trigger, 
         AppearanceElements -> {
          "PlayPauseButton", "ResetButton", "FasterSlowerButtons"}, 
         ControlPlacement -> 8}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Manipulate`Place[5]}, {
           PaneSelector[{0 -> Manipulate`Place[6], 1 -> Row[{
                Text[
                 Style[
                  Subscript[$CellContext`A, $CellContext`x], 12]], 
                Spacer[3], 
                Text[
                 Style["=", 12]], 
                Spacer[3], 
                Text[
                 Style[
                  Dynamic[
                   NumberForm[$CellContext`Ax, {3, 2}]], 12, Italic]], 
                Spacer[20], 
                Text[
                 Style[
                  Subscript[$CellContext`A, $CellContext`y], 12]], 
                Spacer[3], 
                Text[
                 Style["=", 12]], 
                Spacer[3], 
                Text[
                 Style[
                  Dynamic[
                   NumberForm[$CellContext`Ay, {3, 2}]], 12, Italic]], 
                Spacer[20], 
                Text[
                 Style[
                  Subscript[$CellContext`B, $CellContext`y], 12]], Null, 
                Spacer[3], 
                Text[
                 Style["=", 12]], 
                Spacer[3], 
                Text[
                 Style[
                  Dynamic[
                   NumberForm[$CellContext`By, {3, 2}]], 12, Italic]]}]}, 
            Dynamic[$CellContext`opa1$$]]}, {
           PaneSelector[{1 -> Column[{
                Manipulate`Place[7], 
                Manipulate`Place[8], 
                Row[{
                  Text[
                   Style["M", 12, Italic]], 
                  Spacer[3], 
                  Text[
                   Style["=", 12, Italic]], 
                  Spacer[3], 
                  Text[
                   Style[
                    Dynamic[
                    NumberForm[$CellContext`moment, {3, 2}]], 12, Italic]]}]},
                Left, Spacings -> {Automatic, 1.5}]}, 
            Dynamic[$CellContext`rep$$]]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{971., {251., 260.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`sol = {$CellContext`ax -> 
         0., $CellContext`ay -> 1., $CellContext`by -> 
         1.}, $CellContext`fe = {2.25, 0}, $CellContext`fi = {
        2.25, 1}, $CellContext`\[Theta] = Pi/2, $CellContext`m = 
       3, $CellContext`ts = 0, $CellContext`te = 20, $CellContext`Ax = 
       0., $CellContext`Ay = 1., $CellContext`By = 1., $CellContext`moment = 
       0., $CellContext`rot = 
       InterpolatingFunction[{{0., 20.}}, {
         5, 7, 2, {13}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, {{0., 
         0.002052969763803013, 0.004105939527606026, 2.004105939527606, 
         4.004105939527606, 6.004105939527606, 8.004105939527605, 
         10.004105939527605`, 12.004105939527605`, 14.004105939527605`, 
         16.004105939527605`, 18.002052969763803`, 20.}}, {
         Developer`PackedArrayForm, {0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 
          33, 36, 39}, CompressedData["
1:eJxTTMoPSmVkYGBQZxgF5AIASooB0g==
          "]}, {Automatic}], 
       Attributes[Derivative] = {NHoldAll, ReadProtected}, 
       Attributes[Subscript] = {NHoldRest}, 
       Subscript[Notebook$$103$553587`y, Notebook$$103$553587`Gompertz][
        Notebook$$103$553587`t] = 
       Subscript[Notebook$$103$553587`y, Notebook$$103$553587`asym]/
        Notebook$$103$553587`e^(Notebook$$103$553587`b/
         Notebook$$103$553587`e^(Notebook$$103$553587`c 
          Notebook$$103$553587`t)), Subscript[2, Notebook$$103$553587`el] = 
       2/29, Subscript[3.2, Notebook$$103$553587`el] = 0.6400000000000001, 
       Subscript[4.2, Notebook$$103$553587`el] = 0.14, 
       Subscript[5., Notebook$$103$553587`el] = 0.7142857142857142, 
       Subscript[40, 
         Overscript["L", "\[Vee]"]] = 208, Subscript[50, 
         Overscript["L", "\[Vee]"]] = 208, Subscript[C, 0] = 1, 
       Subscript[Notebook$$103$553587`c1, 0] = 0, 
       Subscript[Notebook$$103$553587`c1$10077, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$11173, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$11497, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$11821, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$12145, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$12469, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$7204, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$7664, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$7992, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$8310, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$8634, 0] = 1.5, 
       Subscript[Notebook$$103$553587`c1$9752, 0] = 1.5, 
       Subscript[Notebook$$103$553587`k, 1] = 
       E^(17.34 - 5881.645417368294/(273.15 + Notebook$$103$553587`T)), 
       Subscript[Notebook$$103$553587`k, 2] = 
       E^(42.04 - 14938.65768583113/(273.15 + Notebook$$103$553587`T)), 
       Pattern[Notebook$$103$553587`scaledPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`p, 
           Blank[]], Notebook$$103$553587`scaled]] := 
       Notebook$$103$553587`p Notebook$$103$553587`zoomFct, 
       Pattern[Notebook$$103$553587`tinyPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`x, 
           Blank[]], Notebook$$103$553587`tiny]] := {
        Notebook$$103$553587`x, 2/4}, 
       Pattern[Notebook$$103$553587`smallPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`x, 
           Blank[]], Notebook$$103$553587`small]] := {
        Notebook$$103$553587`x, 3/4}, 
       Pattern[Notebook$$103$553587`nrmlPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`x, 
           Blank[]], Notebook$$103$553587`nrml]] := {
        Notebook$$103$553587`x, 4/4}, Pattern[Notebook$$103$553587`bigPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`x, 
           Blank[]], Notebook$$103$553587`big]] := {
        Notebook$$103$553587`x, 5/4}, 
       Pattern[Notebook$$103$553587`hugePattern, 
         Subscript[
          Pattern[Notebook$$103$553587`x, 
           Blank[]], Notebook$$103$553587`huge]] := {
        Notebook$$103$553587`x, 6/4}, 
       Pattern[Notebook$$103$553587`varPattern$, 
         Subscript[
          Pattern[Notebook$$103$553587`x$, 
           Blank[]], Notebook$$103$553587`varS]] := 
       Subscript[Notebook$$103$553587`x$, 
         Hold[FE`pSize$$280]], Pattern[Notebook$$103$553587`spinLuPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          Overscript["L", "\[Vee]"]]] := 
       Notebook$$103$553587`position[Notebook$$103$553587`e8bit, 
         Notebook$$103$553587`pBit[Notebook$$103$553587`prt]], 
       Pattern[Notebook$$103$553587`spinLdPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          Overscript["R", "\[Wedge]"]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8bit, 
         Notebook$$103$553587`pBit[Notebook$$103$553587`prt] + 
         2^Part[Notebook$$103$553587`bOrd, 4]], 
       Pattern[Notebook$$103$553587`spinRuPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          Overscript["L", "\[Wedge]"]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8bit, 
         Notebook$$103$553587`pBit[Notebook$$103$553587`prt] + 
         2^(Part[Notebook$$103$553587`bOrd, 4] + 1)], 
       Pattern[Notebook$$103$553587`spinRdPattern, 
         Subscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          Overscript["R", "\[Vee]"]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8bit, 
         Notebook$$103$553587`pBit[Notebook$$103$553587`prt] + 
         2^Part[Notebook$$103$553587`bOrd, 4] + 
         2^(Part[Notebook$$103$553587`bOrd, 4] + 1)], Notebook$$103$553587`y[
         Pattern[Notebook$$103$553587`t, 
          Blank[]], 
         Pattern[Notebook$$103$553587`tInflecW, 
          Blank[]], 
         Pattern[Notebook$$103$553587`yInflecW, 
          Blank[]], 
         Pattern[Notebook$$103$553587`muMaxW, 
          Blank[]]] := 
       Notebook$$103$553587`yInflecW + 
        Notebook$$103$553587`muMaxW (Notebook$$103$553587`t - 
          Notebook$$103$553587`tInflecW), 
       Attributes[Notebook$$103$553587`c1$10077] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$11821] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$7992] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$12469] = {Temporary}, 
       Attributes[Overscript] = {NHoldRest}, 
       Overscript[Notebook$$103$553587`l1, 
         Blank[]] = {74, 13, 163}, Overscript[Notebook$$103$553587`l2, 
         Blank[]] = {185, 109, 247}, 
       Overscript[{183, 244, 94, 72, 148, 10, 192, 238, 23, 81, 128, 1, 203, 
         233, 18, 216, 162, 17, 48, 229, 12, 61, 158, 11}, 
         Blank[]] = {74, 13, 163, 185, 109, 247, 65, 19, 234, 176, 129, 256, 
        54, 24, 239, 41, 95, 240, 209, 28, 245, 196, 99, 246}, 
       Overscript[Notebook$$103$553587`q1, 
         Blank[]] = {191, 14, 32}, Overscript[Notebook$$103$553587`q2, 
         Blank[]] = {80, 110, 149}, 
       Overscript[{66, 243, 225, 177, 147, 108, 67, 242, 224, 178, 146, 107, 
         68, 241, 223, 179, 145, 106, 75, 237, 154, 186, 127, 37, 76, 236, 
         153, 187, 126, 36, 77, 235, 152, 188, 125, 35, 210, 232, 144, 197, 
         161, 138, 211, 231, 143, 198, 160, 137, 212, 230, 142, 199, 159, 136,
          55, 228, 124, 42, 157, 118, 56, 227, 123, 43, 156, 117, 57, 226, 
         122, 44, 155, 116}, 
         Blank[]] = {191, 14, 32, 80, 110, 149, 190, 15, 33, 79, 111, 150, 
        189, 16, 34, 78, 112, 151, 182, 20, 103, 71, 130, 220, 181, 21, 104, 
        70, 131, 221, 180, 22, 105, 69, 132, 222, 47, 25, 113, 60, 96, 119, 
        46, 26, 114, 59, 97, 120, 45, 27, 115, 58, 98, 121, 202, 29, 133, 215,
         100, 139, 201, 30, 134, 214, 101, 140, 200, 31, 135, 213, 102, 141}, 
       Overscript[Notebook$$103$553587`\[Omega]g1, 
         Blank[]] = {167, 166, 164}, 
       Overscript[Notebook$$103$553587`\[Omega]g2, 
         Blank[]] = {64, 206, 38}, Overscript[{90, 91, 93, 193, 51, 219}, 
         Blank[]] = {167, 166, 164, 64, 206, 38}, 
       Overscript[Notebook$$103$553587`\[Phi]\[CapitalPhi]1, 
         Blank[]] = {170, 171, 172}, 
       Overscript[Notebook$$103$553587`\[Phi]\[CapitalPhi]2, 
         Blank[]] = {53, 50, 40}, 
       Overscript[{87, 92, 175, 86, 89, 174, 85, 88, 173, 204, 195, 218, 207, 
         205, 194, 217, 49, 73}, 
         Blank[]] = {170, 165, 82, 171, 168, 83, 172, 169, 84, 53, 62, 39, 50,
         52, 63, 40, 208, 184}, Overscript[
         Subscript[Notebook$$103$553587`Ex, 1], 
         Blank[]] = 2, Overscript[Notebook$$103$553587`ex1, 
         Blank[]] = {2, 3, 4, 5}, Overscript[
         Subscript[Notebook$$103$553587`Ex, 2], 
         Blank[]] = 6, Overscript[Notebook$$103$553587`ex2, 
         Blank[]] = {6, 7, 8, 9}, 
       Overscript[{255, 251, 254, 250, 253, 249, 252, 248}, 
         Blank[]] = {2, 6, 3, 7, 4, 8, 5, 9}, Overscript[{183, 244, 94}, 
         Blank[]] = {74, 13, 163}, Overscript[{72, 148, 10}, 
         Blank[]] = {185, 109, 247}, Overscript[{66, 243, 225}, 
         Blank[]] = {191, 14, 32}, Overscript[{177, 147, 108}, 
         Blank[]] = {80, 110, 149}, Overscript[{90, 91, 93}, 
         Blank[]] = {167, 166, 164}, Overscript[{193, 51, 219}, 
         Blank[]] = {64, 206, 38}, Overscript[{87, 86, 85}, 
         Blank[]] = {170, 171, 172}, Overscript[{204, 207, 217}, 
         Blank[]] = {53, 50, 40}, Overscript[{255, 254, 253, 252}, 
         Blank[]] = {2, 3, 4, 5}, Overscript[{251, 250, 249, 248}, 
         Blank[]] = {6, 7, 8, 9}, Notebook$$103$553587`l1 = {183, 244, 94}, 
       Notebook$$103$553587`l2 = {72, 148, 10}, 
       Notebook$$103$553587`q1 = {66, 243, 225}, 
       Notebook$$103$553587`q2 = {177, 147, 108}, 
       Notebook$$103$553587`\[Omega]g1 = {90, 91, 93}, 
       Notebook$$103$553587`\[Omega]g2 = {193, 51, 219}, 
       Notebook$$103$553587`\[Phi]\[CapitalPhi]1 = {87, 86, 85}, 
       Notebook$$103$553587`\[Phi]\[CapitalPhi]2 = {204, 207, 217}, 
       Notebook$$103$553587`ex1 = {255, 254, 253, 252}, 
       Notebook$$103$553587`ex2 = {251, 250, 249, 248}, 
       Attributes[Notebook$$103$553587`c1$8310] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$11497] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$7204] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$12145] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$11173] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$8634] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$7664] = {Temporary}, 
       Attributes[Notebook$$103$553587`c1$9752] = {Temporary}, 
       Notebook$$103$553587`zoomFct := 1. 10^FE`zoom$$280, FE`zoom$$280 = 0, 
       Attributes[Notebook$$103$553587`x$] = {Temporary}, FE`pSize$$280 = 
       Notebook$$103$553587`nrml, Notebook$$103$553587`position[
         Pattern[Notebook$$103$553587`x, 
          Blank[]], 
         Pattern[Notebook$$103$553587`y, 
          Blank[]]] := Notebook$$103$553587`first[
         Flatten[
          Position[
          Notebook$$103$553587`x, Notebook$$103$553587`y, 1, Heads -> 
           False]]], Notebook$$103$553587`first[
         Pattern[Notebook$$103$553587`in, 
          Blank[]]] := 
       If[Length[Notebook$$103$553587`in] == 0, Notebook$$103$553587`in, 
         First[Notebook$$103$553587`in]], 
       Notebook$$103$553587`e8bit = {71, 128, 132, 136, 140, 192, 196, 200, 
        204, 67, 79, 15, 130, 146, 162, 178, 75, 11, 134, 150, 166, 182, 7, 
        138, 154, 170, 186, 142, 158, 174, 190, 147, 163, 179, 119, 103, 87, 
        240, 220, 244, 201, 93, 109, 125, 185, 169, 153, 13, 120, 228, 96, 
        232, 212, 137, 29, 45, 61, 249, 233, 217, 77, 216, 236, 208, 133, 17, 
        33, 49, 245, 229, 213, 65, 124, 129, 21, 37, 53, 241, 225, 209, 69, 
        156, 172, 188, 52, 36, 20, 56, 40, 16, 32, 24, 48, 3, 202, 218, 234, 
        250, 206, 222, 238, 254, 151, 167, 183, 115, 99, 83, 194, 210, 226, 
        242, 155, 171, 187, 127, 111, 95, 219, 235, 251, 63, 47, 31, 118, 102,
         86, 70, 198, 214, 230, 246, 159, 175, 191, 123, 107, 91, 223, 239, 
        255, 59, 43, 27, 114, 98, 82, 66, 211, 227, 243, 55, 39, 23, 126, 110,
         94, 78, 122, 106, 90, 74, 131, 176, 152, 160, 144, 168, 184, 148, 
        164, 180, 60, 44, 28, 197, 81, 97, 113, 181, 165, 149, 1, 252, 193, 
        85, 101, 117, 177, 161, 145, 5, 80, 108, 88, 205, 89, 105, 121, 189, 
        173, 157, 9, 84, 104, 224, 100, 248, 141, 25, 41, 57, 253, 237, 221, 
        73, 116, 92, 112, 215, 231, 247, 51, 35, 19, 62, 46, 30, 14, 58, 42, 
        26, 10, 135, 54, 38, 22, 6, 139, 203, 50, 34, 18, 2, 143, 207, 195, 
        76, 72, 68, 64, 12, 8, 4, 0, 199}, Notebook$$103$553587`pBit[
         Pattern[Notebook$$103$553587`p, 
          Blank[]]] := Part[Notebook$$103$553587`e8b, 
         Min[Notebook$$103$553587`p, 256], Notebook$$103$553587`sets + 2], 
       Notebook$$103$553587`e8b = {{1, 71, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {2, 128, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"y", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {3, 132, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"y", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {4, 136, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"y", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {5, 140, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"y", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {6, 192, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {7, 196, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {8, 200, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {9, 204, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {10, 67, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {11, 79, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {12, 15, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {13, 130, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"y", "d"}, {
          Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {14, 146, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "d"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {15, 162, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "d"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {16, 178, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "d"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {17, 75, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {18, 11, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {19, 134, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"y", "l"}, {
          Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {20, 150, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "l"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {21, 166, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "l"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {22, 182, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "l"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {23, 7, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"y", "l"}, {
          Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {24, 138, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {25, 154, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {26, 170, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {27, 186, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {28, 142, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {29, 158, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {30, 174, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {31, 190, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {32, 147, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "d"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {33, 163, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "d"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {34, 179, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "d"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {35, 119, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "l"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {36, 103, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "l"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {37, 87, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "l"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {38, 240, 
          HoldForm[HoldForm[
             Underoverscript["W", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[80403.`5., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[3.076`4.*^-25, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {39, 220, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {40, 244, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["b", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {41, 201, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {42, 93, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {43, 109, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {44, 125, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {45, 185, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {46, 169, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {47, 153, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {48, 13, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {49, 120, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["b", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {50, 228, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {51, 96, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Omega]", "R"], 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {52, 232, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {53, 212, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {54, 137, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {55, 29, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {56, 45, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {57, 61, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {58, 249, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {59, 233, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {60, 217, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {61, 77, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {62, 216, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {63, 236, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {64, 208, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Omega]", "L"], 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {65, 133, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"y", "l"}, {
          Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {66, 17, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "d"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {67, 33, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "d"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {68, 49, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "d"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {69, 245, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "l"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {70, 229, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "l"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {71, 213, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "l"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {72, 65, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {73, 124, 
          HoldForm[HoldForm[
             Underoverscript["B", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[91187.6`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[
            2.637899999999999999999999999999999`5.*^-25, 10, 
             NumberPadding -> {" ", "0"}], " S"}]}, {74, 129, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"y", "d"}, {
          Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {75, 21, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "l"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {76, 37, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "l"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {77, 53, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "l"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {78, 241, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "d"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {79, 225, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "d"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {80, 209, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "d"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {81, 69, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {82, 156, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"o", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {83, 172, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"c", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {84, 188, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"m", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {85, 52, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"m", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {86, 36, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"c", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {87, 20, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"o", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {88, 56, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"m", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {89, 40, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"c", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {90, 16, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"g", 
                 Overscript["b", "_"]}]], 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"o", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {91, 32, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"r", 
                 Overscript["b", "_"]}]], 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"c", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {92, 24, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"o", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {93, 48, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"r", 
                 Overscript["g", "_"]}]], 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"m", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {94, 3, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"y", "d"}, {
          Notebook$$103$553587`tri, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {95, 202, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {96, 218, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {97, 234, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {98, 250, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {99, 206, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {100, 222, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {101, 238, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {102, 254, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {103, 151, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "l"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {104, 167, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "l"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {105, 183, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "l"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {106, 115, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "d"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {107, 99, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "d"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {108, 83, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "d"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}],
           
          Row[{"?", " S"}]}, {109, 194, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {110, 210, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "d"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {111, 226, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "d"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {112, 242, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "d"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {113, 155, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {114, 171, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {115, 187, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {116, 127, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {117, 111, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {118, 95, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {119, 219, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {120, 235, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {121, 251, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {122, 63, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {123, 47, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {124, 31, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {125, 118, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "l"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {126, 102, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "l"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {127, 86, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "l"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {128, 70, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {129, 198, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`utr, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {130, 214, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "l"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {131, 230, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "l"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {132, 246, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "l"}, {
          Notebook$$103$553587`dia, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {133, 159, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {134, 175, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {135, 191, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {136, 123, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {137, 107, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {138, 91, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {139, 223, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {140, 239, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {141, 255, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {142, 59, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {143, 43, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {144, 27, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {145, 114, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "d"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {146, 98, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "d"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {147, 82, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "d"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {148, 66, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {149, 211, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "d"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {150, 227, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "d"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {151, 243, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "d"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {152, 55, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "l"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {153, 39, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "l"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {154, 23, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "l"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {155, 126, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {156, 110, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {157, 94, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {158, 78, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {159, 122, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {160, 106, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {161, 90, 
          HoldForm[HoldForm[
             Underoverscript["c", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[1250.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {162, 74, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Mu]"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[0``1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {163, 131, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"y", "d"}, {
          Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {164, 176, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"r", 
                 Overscript["g", "_"]}]], 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"m", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {165, 152, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"o", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {166, 160, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"r", 
                 Overscript["b", "_"]}]], 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"c", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {167, 144, 
          HoldForm[HoldForm[
             Underoverscript[
              Superscript["g", 
               Row[{"g", 
                 Overscript["b", "_"]}]], 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "+"]]], {"o", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {168, 168, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"c", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {169, 184, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"m", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {170, 148, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"o", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {171, 164, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"c", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {172, 180, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"m", "d"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {173, 60, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "3"], "\[CapitalPhi]"}], 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"m", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {174, 44, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "2"], "\[CapitalPhi]"}], 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"c", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {175, 28, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["x", "1"], "\[CapitalPhi]"}], 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"o", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {176, 197, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {177, 81, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "d"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {178, 97, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "d"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {179, 113, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "d"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {180, 181, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "l"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {181, 165, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "l"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {182, 149, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "l"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {183, 1, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"y", "d"}, {
          Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {184, 252, 
          HoldForm[HoldForm[
             Underoverscript["B", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[91187.6`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[
            2.637899999999999999999999999999999`5.*^-25, 10, 
             NumberPadding -> {" ", "0"}], " S"}]}, {185, 193, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {186, 85, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "l"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {187, 101, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "l"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {188, 117, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "l"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {189, 177, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "d"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {190, 161, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "d"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {191, 145, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "d"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {192, 5, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"y", "l"}, {
          Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {193, 80, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Omega]", "L"], 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {194, 108, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {195, 88, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {196, 205, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {197, 89, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "r", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {198, 105, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "g", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {199, 121, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`2\/3\)"]]], {
          "b", "m"}, {Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {200, 189, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "m", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {201, 173, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "c", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {202, 157, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`1\/3\)"]]], {
          "o", "m"}, {Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {203, 9, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {204, 84, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {205, 104, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {206, 224, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Omega]", "R"], 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "m"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {207, 100, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["g", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "g", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {208, 248, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "T"], "\[CapitalPhi]"}], 
              Subscript["b", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "l"}, 
          Subscript[Notebook$$103$553587`inv, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {209, 141, 
          HoldForm[HoldForm[
             Underoverscript["e", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 1/2}, 1, 
          Row[{
            NumberForm[0.51099892`8., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{"?", " S"}]}, {210, 25, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {211, 41, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {212, 57, 
          HoldForm[HoldForm[
             Underoverscript["d", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 1/2}, 2, 
          Row[{
            NumberForm[5.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {213, 253, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["b", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {214, 237, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["g", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {215, 221, 
          HoldForm[HoldForm[
             Underoverscript["u", 
              Subscript["r", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "m"}, {
          Notebook$$103$553587`dia, 1/2}, 2, 
          Row[{
            NumberForm[2.2`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {216, 73, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "e"], 
              Subscript["w", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`tri, 1/2}, 1, 
          Row[{
            NumberForm[0``6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {217, 116, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["b", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {218, 92, 
          HoldForm[HoldForm[
             Underoverscript[
              Row[{
                Subscript["e", "S"], "\[CapitalPhi]"}], 
              Subscript["r", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "r", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 4, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {219, 112, 
          HoldForm[HoldForm[
             Underoverscript["W", 
              Subscript["b", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "b", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 3, 
          Row[{
            NumberForm[80403.`5., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[3.076`4.*^-25, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {220, 215, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["r", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"r", "l"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {221, 231, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["g", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"g", "l"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {222, 247, 
          HoldForm[HoldForm[
             Underoverscript["t", 
              Subscript["b", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(2\/3\)\)\)\)"]]], {"b", "l"}, {
          Notebook$$103$553587`dia, 3/2}, 2, 
          Row[{
            NumberForm[174200.`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {223, 51, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["m", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "d"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {224, 35, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["c", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "d"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {225, 19, 
          HoldForm[HoldForm[
             Underoverscript["b", 
              Subscript["o", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "d"}, {
          Notebook$$103$553587`squ, 3/2}, 2, 
          Row[{
            NumberForm[4200.`4., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {226, 62, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {227, 46, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {228, 30, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {229, 14, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {230, 58, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {231, 42, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {232, 26, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "m"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {233, 10, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "m"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"y", "m"}, {
          Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {234, 135, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "+"]]], {"y", "l"}, {
          Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {235, 54, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "l"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {236, 38, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "l"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {237, 22, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "l"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {238, 6, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "l"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"y", "l"}, {
          Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {239, 139, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {240, 203, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {241, 50, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["m", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"m", "d"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {242, 34, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["c", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"c", "d"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {243, 18, 
          HoldForm[HoldForm[
             Underoverscript["s", 
              Subscript["o", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], 
              "\!\(TraditionalForm\`\(-\(\(1\/3\)\)\)\)"]]], {"o", "d"}, {
          Notebook$$103$553587`squ, 1}, 2, 
          Row[{
            NumberForm[95.`2., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {244, 2, 
          HoldForm[HoldForm[
             Underoverscript["\[Mu]", 
              Subscript["y", "d"], ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"y", "d"}, {
          Notebook$$103$553587`tri, 1}, 1, 
          Row[{
            NumberForm[105.658369`9., 10, NumberPadding -> {" ", "0"}], 
            " MeV"}], 
          Row[{
            NumberForm[2.19704`6.*^-6, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {245, 143, 
          HoldForm[HoldForm[
             Underoverscript["\[Tau]", 
              Subscript["y", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "+"]]], {"y", "m"}, {
          Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[1776.99`6., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{
            NumberForm[2.906`4.*^-13, 10, NumberPadding -> {" ", "0"}], 
            " S"}]}, {246, 207, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "m"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, {Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {247, 195, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "d"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, {Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {248, 76, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {249, 72, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {250, 68, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {251, 64, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "2"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {252, 12, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Vee]"], "-"]]], {"y", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {253, 8, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Wedge]"], "-"]]], {"y", "m"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {254, 4, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "-"]]], {"y", "l"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {255, 0, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["Ex", "1"], "\" \"", ""]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["L", "\[Vee]"], "-"]]], {"y", "d"}, 
          Subscript[Notebook$$103$553587`cir, 
           Hold[FE`pSize$$280]], 5, 
          Row[{
            NumberForm[0``16., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}, {256, 199, 
          HoldForm[HoldForm[
             Underoverscript[
              Subscript["\[Nu]", "\[Tau]"], 
              Subscript["w", "l"], 
              Blank[]]] HoldForm[
             Subsuperscript[
              Invisible[Notebook$$103$553587`\[VerticalLine]], 
              Overscript["R", "\[Wedge]"], "\!\(TraditionalForm\`0\)"]]], {
          "w", "l"}, {Notebook$$103$553587`utr, 3/2}, 1, 
          Row[{
            NumberForm[0``-1., 10, NumberPadding -> {" ", "0"}], " MeV"}], 
          Row[{"?", " S"}]}}, Attributes[Underoverscript] = {NHoldRest}, 
       Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`r, 
            Overscript[Notebook$$103$553587`b, 
             Blank[]]}]], Notebook$$103$553587`rb, 
         Blank[]] = 166, Underoverscript[
         Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`R], 
         Notebook$$103$553587`rb, 
         Blank[]] = 206, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`x, 2], 
           Notebook$$103$553587`\[CapitalPhi]}], Notebook$$103$553587`rb, 
         Blank[]] = 171, 
       Underoverscript[Notebook$$103$553587`B, Notebook$$103$553587`rb, 
         Blank[]] = 50, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`T], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`rb, 
         Blank[]] = 50, Pattern[Notebook$$103$553587`colorGreenPattern, 
         Underoverscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`rb, 
          Blank[]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8bit, Notebook$$103$553587`pBit[
           Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`bg, 
            Blank[]]] + 2^Part[Notebook$$103$553587`bOrd, 3]], Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`r, 
            Overscript[Notebook$$103$553587`g, 
             Blank[]]}]], Notebook$$103$553587`rg, 
         Blank[]] = 164, 
       Underoverscript[Notebook$$103$553587`W, Notebook$$103$553587`rg, 
         Blank[]] = 38, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`x, 3], 
           Notebook$$103$553587`\[CapitalPhi]}], Notebook$$103$553587`rg, 
         Blank[]] = 172, 
       Underoverscript[Notebook$$103$553587`B, Notebook$$103$553587`rg, 
         Blank[]] = 40, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`S], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`rg, 
         Blank[]] = 40, Pattern[Notebook$$103$553587`colorBluePattern, 
         Underoverscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`rg, 
          Blank[]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8bit, Notebook$$103$553587`pBit[
           Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`bg, 
            Blank[]]] + 2^(Part[Notebook$$103$553587`bOrd, 3] + 1)], 
       Pattern[Notebook$$103$553587`particlePattern, 
         Underoverscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          Subscript[
           Pattern[Notebook$$103$553587`clr, 
            Blank[]], 
           Pattern[Notebook$$103$553587`sp, 
            Blank[]]], 
          Pattern[Notebook$$103$553587`anti, 
           Blank[]]]] := Notebook$$103$553587`spConv[
         If[Notebook$$103$553587`anti == "", False, True], 
         Notebook$$103$553587`prt, Notebook$$103$553587`clr, 
         Notebook$$103$553587`sp], 
       Underoverscript[Notebook$$103$553587`e, Notebook$$103$553587`bg, 
         Blank[]] = 74, 
       Underoverscript[Notebook$$103$553587`e, Notebook$$103$553587`y, 
         Blank[]] = 74, 
       Underoverscript[Notebook$$103$553587`\[Mu], Notebook$$103$553587`y, 
         Blank[]] = 13, 
       Underoverscript[Notebook$$103$553587`\[Tau], Notebook$$103$553587`y, 
         Blank[]] = 163, Underoverscript[
         Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`e], 
         Notebook$$103$553587`y, 
         Blank[]] = 185, Underoverscript[
         Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`e], 
         Notebook$$103$553587`bg, 
         Blank[]] = 185, 
       Underoverscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`y, 
         Blank[]] = 185, Underoverscript[
         Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`\[Mu]], 
         Notebook$$103$553587`y, 
         Blank[]] = 109, Underoverscript[
         Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`\[Tau]], 
         Notebook$$103$553587`y, 
         Blank[]] = 247, 
       Underoverscript[Notebook$$103$553587`d, Notebook$$103$553587`bg, 
         Blank[]] = 191, 
       Underoverscript[Notebook$$103$553587`s, Notebook$$103$553587`bg, 
         Blank[]] = 14, 
       Underoverscript[Notebook$$103$553587`b, Notebook$$103$553587`bg, 
         Blank[]] = 32, 
       Underoverscript[Notebook$$103$553587`u, Notebook$$103$553587`bg, 
         Blank[]] = 80, 
       Underoverscript[Notebook$$103$553587`c, Notebook$$103$553587`bg, 
         Blank[]] = 110, 
       Underoverscript[Notebook$$103$553587`t, Notebook$$103$553587`bg, 
         Blank[]] = 149, Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`g, 
            Overscript[Notebook$$103$553587`b, 
             Blank[]]}]], Notebook$$103$553587`bg, 
         Blank[]] = 167, Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`g, 
            Overscript[Notebook$$103$553587`b, 
             Blank[]]}]], Notebook$$103$553587`y, 
         Blank[]] = 167, 
       Underoverscript[Notebook$$103$553587`g, Notebook$$103$553587`y, 
         Blank[]] = 167, 
       Underoverscript[Notebook$$103$553587`g, Notebook$$103$553587`bg, 
         Blank[]] = 167, Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`r, 
            Overscript[Notebook$$103$553587`b, 
             Blank[]]}]], Notebook$$103$553587`y, 
         Blank[]] = 166, Underoverscript[
         Superscript[Notebook$$103$553587`g, 
          Row[{Notebook$$103$553587`r, 
            Overscript[Notebook$$103$553587`g, 
             Blank[]]}]], Notebook$$103$553587`y, 
         Blank[]] = 164, Underoverscript[
         Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`L], 
         Notebook$$103$553587`bg, 
         Blank[]] = 64, Underoverscript[
         Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`L], 
         Notebook$$103$553587`y, 
         Blank[]] = 64, 
       Underoverscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`y, 
         Blank[]] = 64, 
       Underoverscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`bg, 
         Blank[]] = 64, Underoverscript[
         Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`R], 
         Notebook$$103$553587`y, 
         Blank[]] = 206, 
       Underoverscript[Notebook$$103$553587`W, Notebook$$103$553587`y, 
         Blank[]] = 38, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`x, 1], 
           Notebook$$103$553587`\[CapitalPhi]}], Notebook$$103$553587`bg, 
         Blank[]] = 170, 
       Underoverscript[
        Notebook$$103$553587`\[CapitalPhi], Notebook$$103$553587`y, 
         Blank[]] = 170, 
       Underoverscript[
        Notebook$$103$553587`\[CapitalPhi], Notebook$$103$553587`bg, 
         Blank[]] = 170, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`x, 2], 
           Notebook$$103$553587`\[CapitalPhi]}], Notebook$$103$553587`bg, 
         Blank[]] = 171, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`x, 3], 
           Notebook$$103$553587`\[CapitalPhi]}], Notebook$$103$553587`bg, 
         Blank[]] = 172, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`S], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`bg, 
         Blank[]] = 53, 
       Underoverscript[Notebook$$103$553587`\[Phi], Notebook$$103$553587`y, 
         Blank[]] = 53, 
       Underoverscript[Notebook$$103$553587`\[Phi], Notebook$$103$553587`bg, 
         Blank[]] = 53, 
       Underoverscript[Notebook$$103$553587`B, Notebook$$103$553587`bg, 
         Blank[]] = 53, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`T], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`y, 
         Blank[]] = 50, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`T], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`bg, 
         Blank[]] = 50, Underoverscript[
         Row[{
           Subscript[Notebook$$103$553587`e, Notebook$$103$553587`S], 
           Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`y, 
         Blank[]] = 40, Attributes[Superscript] = {NHoldRest, ReadProtected}, 
       Notebook$$103$553587`bOrd = {7, 6, 4, 2, 0}, 
       Notebook$$103$553587`spConv[
         Pattern[Notebook$$103$553587`anti, 
          Blank[]], 
         Pattern[Notebook$$103$553587`prt, 
          Blank[]], 
         Pattern[Notebook$$103$553587`clr, 
          Blank[]], 
         Pattern[Notebook$$103$553587`sp, 
          Blank[]]] := 
       Notebook$$103$553587`position[Notebook$$103$553587`e8Orig, 
         If[Notebook$$103$553587`anti, Subtract, Plus][0, 
          Part[Notebook$$103$553587`e8Orig, 
           Notebook$$103$553587`position[
           Notebook$$103$553587`e8bit, Notebook$$103$553587`pBit[
              Underscript[
               Part[
                Flatten[Notebook$$103$553587`flavorList], 
                Notebook$$103$553587`position[
                 Flatten[Notebook$$103$553587`flavorListStr], 
                 ReplaceAll[
                 Notebook$$103$553587`prt, 
                  Notebook$$103$553587`qConvDoNoAnti]]], 
               If[
               Notebook$$103$553587`clr == "\" \"", Notebook$$103$553587`clr, 
                Part[Notebook$$103$553587`colorListExp, 
                 Notebook$$103$553587`position[
                 Notebook$$103$553587`colorList, 
                  Notebook$$103$553587`clr]]]]] + 
            Switch[Notebook$$103$553587`sp, 
              Part[Notebook$$103$553587`spList, 1], 0, 
              Part[Notebook$$103$553587`spList, 2], 2^
              Part[Notebook$$103$553587`bOrd, 4], 
              Part[Notebook$$103$553587`spList, 3], 
              2^(Part[Notebook$$103$553587`bOrd, 4] + 1), 
              Part[Notebook$$103$553587`spList, 4], 
              2^Part[Notebook$$103$553587`bOrd, 4] + 
              2^(Part[Notebook$$103$553587`bOrd, 4] + 1)]]]]], 
       Notebook$$103$553587`e8Orig = {{(-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/
          2, (-1)/2, (-1)/2, (-1)/2}, {0, 0, 0, 0, 0, 0, 0, -1}, {0, 0, 0, 0, 
         0, 0, -1, 0}, {0, 0, 0, 0, 0, -1, 0, 0}, {0, 0, 0, 0, -1, 0, 0, 0}, {
         0, 0, 0, -1, 0, 0, 0, 0}, {0, 0, -1, 0, 0, 0, 0, 0}, {0, -1, 0, 0, 0,
          0, 0, 0}, {-1, 0, 0, 0, 0, 0, 0, 0}, {
         1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2}, {(-1)/2, 
          1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/
          2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, (-1)/
          2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2, (-1)/
          2, (-1)/2, 1/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/
          2, (-1)/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/
          2, (-1)/2, 1/2}, {(-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/
          2, (-1)/2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/
          2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/
          2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/
          2}, {(-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/
          2}, {-1, -1, 0, 0, 0, 0, 0, 0}, {-1, 0, -1, 0, 0, 0, 0, 0}, {-1, 0, 
         0, -1, 0, 0, 0, 0}, {-1, 0, 0, 0, -1, 0, 0, 0}, {-1, 0, 0, 0, 0, -1, 
         0, 0}, {-1, 0, 0, 0, 0, 0, -1, 0}, {-1, 0, 0, 0, 0, 0, 0, -1}, {-1, 
         0, 0, 0, 0, 0, 0, 1}, {-1, 0, 0, 0, 0, 0, 1, 0}, {-1, 0, 0, 0, 0, 1, 
         0, 0}, {-1, 0, 0, 0, 1, 0, 0, 0}, {-1, 0, 0, 1, 0, 0, 0, 0}, {-1, 0, 
         1, 0, 0, 0, 0, 0}, {-1, 1, 0, 0, 0, 0, 0, 0}, {0, -1, -1, 0, 0, 0, 0,
          0}, {0, -1, 0, -1, 0, 0, 0, 0}, {0, -1, 0, 0, -1, 0, 0, 0}, {0, -1, 
         0, 0, 0, -1, 0, 0}, {0, -1, 0, 0, 0, 0, -1, 0}, {0, -1, 0, 0, 0, 0, 
         0, -1}, {0, -1, 0, 0, 0, 0, 0, 1}, {0, -1, 0, 0, 0, 0, 1, 0}, {0, -1,
          0, 0, 0, 1, 0, 0}, {0, -1, 0, 0, 1, 0, 0, 0}, {0, -1, 0, 1, 0, 0, 0,
          0}, {0, -1, 1, 0, 0, 0, 0, 0}, {0, 0, -1, -1, 0, 0, 0, 0}, {0, 
         0, -1, 0, -1, 0, 0, 0}, {0, 0, -1, 0, 0, -1, 0, 0}, {0, 0, -1, 0, 0, 
         0, -1, 0}, {0, 0, -1, 0, 0, 0, 0, -1}, {0, 0, -1, 0, 0, 0, 0, 1}, {0,
          0, -1, 0, 0, 0, 1, 0}, {0, 0, -1, 0, 0, 1, 0, 0}, {0, 0, -1, 0, 1, 
         0, 0, 0}, {0, 0, -1, 1, 0, 0, 0, 0}, {0, 0, 0, -1, -1, 0, 0, 0}, {0, 
         0, 0, -1, 0, -1, 0, 0}, {0, 0, 0, -1, 0, 0, -1, 0}, {0, 0, 0, -1, 0, 
         0, 0, -1}, {0, 0, 0, -1, 0, 0, 0, 1}, {0, 0, 0, -1, 0, 0, 1, 0}, {0, 
         0, 0, -1, 0, 1, 0, 0}, {0, 0, 0, -1, 1, 0, 0, 0}, {0, 0, 0, 
         0, -1, -1, 0, 0}, {0, 0, 0, 0, -1, 0, -1, 0}, {0, 0, 0, 0, -1, 0, 
         0, -1}, {0, 0, 0, 0, -1, 0, 0, 1}, {0, 0, 0, 0, -1, 0, 1, 0}, {0, 0, 
         0, 0, -1, 1, 0, 0}, {0, 0, 0, 0, 0, -1, -1, 0}, {0, 0, 0, 0, 0, -1, 
         0, -1}, {0, 0, 0, 0, 0, -1, 0, 1}, {0, 0, 0, 0, 0, -1, 1, 0}, {0, 0, 
         0, 0, 0, 0, -1, -1}, {0, 0, 0, 0, 0, 0, -1, 1}, {
         1/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2}, {
         1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2}, {(-1)/2, 1/2, 1/
          2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, 1/2, 1/2, (-1)/
          2, 1/2, (-1)/2, (-1)/2}, {(-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/
          2, (-1)/2}, {(-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/
          2}, {(-1)/2, 1/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2}, {(-1)/2, 
          1/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2}, {(-1)/2, 1/2, 1/
          2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2}, {(-1)/2, 1/2, 1/2, (-1)/
          2, (-1)/2, 1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/
          2, (-1)/2, 1/2}, {(-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/
          2}, {(-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2}, {(-1)/2, 
          1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2, 
          1/2, 1/2, (-1)/2, (-1)/2, 1/2}, {(-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 
          1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 
          1/2}, {(-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2}, {(-1)/2,
           1/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, (-1)/
          2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2}, {(-1)/2, 1/2, (-1)/2, (-1)/2, 1/
          2, (-1)/2, 1/2, 1/2}, {(-1)/2, 1/2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/
          2, 1/2}, {(-1)/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/
          2}, {(-1)/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2}, {(-1)/
          2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2}, {(-1)/2, (-1)/2, 1/
          2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2}, {(-1)/2, (-1)/2, 1/2, 1/2, (-1)/
          2, 1/2, (-1)/2, 1/2}, {(-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/
          2, 1/2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/
          2}, {(-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2}, {(-1)/
          2, (-1)/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2}, {(-1)/2, (-1)/2, 1/
          2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, 1/
          2, 1/2, 1/2, (-1)/2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/
          2, 1/2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, 1/
          2}, {(-1)/2, (-1)/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2}, {(-1)/
          2, (-1)/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, 1/2}, {0, 0, 0, 0, 0, 0, 
         1, -1}, {0, 0, 0, 0, 0, 0, 1, 1}, {0, 0, 0, 0, 0, 1, -1, 0}, {0, 0, 
         0, 0, 0, 1, 0, -1}, {0, 0, 0, 0, 0, 1, 0, 1}, {0, 0, 0, 0, 0, 1, 1, 
         0}, {0, 0, 0, 0, 1, -1, 0, 0}, {0, 0, 0, 0, 1, 0, -1, 0}, {0, 0, 0, 
         0, 1, 0, 0, -1}, {0, 0, 0, 0, 1, 0, 0, 1}, {0, 0, 0, 0, 1, 0, 1, 
         0}, {0, 0, 0, 0, 1, 1, 0, 0}, {0, 0, 0, 1, -1, 0, 0, 0}, {0, 0, 0, 1,
          0, -1, 0, 0}, {0, 0, 0, 1, 0, 0, -1, 0}, {0, 0, 0, 1, 0, 0, 
         0, -1}, {0, 0, 0, 1, 0, 0, 0, 1}, {0, 0, 0, 1, 0, 0, 1, 0}, {0, 0, 0,
          1, 0, 1, 0, 0}, {0, 0, 0, 1, 1, 0, 0, 0}, {0, 0, 1, -1, 0, 0, 0, 
         0}, {0, 0, 1, 0, -1, 0, 0, 0}, {0, 0, 1, 0, 0, -1, 0, 0}, {0, 0, 1, 
         0, 0, 0, -1, 0}, {0, 0, 1, 0, 0, 0, 0, -1}, {0, 0, 1, 0, 0, 0, 0, 
         1}, {0, 0, 1, 0, 0, 0, 1, 0}, {0, 0, 1, 0, 0, 1, 0, 0}, {0, 0, 1, 0, 
         1, 0, 0, 0}, {0, 0, 1, 1, 0, 0, 0, 0}, {0, 1, -1, 0, 0, 0, 0, 0}, {0,
          1, 0, -1, 0, 0, 0, 0}, {0, 1, 0, 0, -1, 0, 0, 0}, {0, 1, 0, 0, 
         0, -1, 0, 0}, {0, 1, 0, 0, 0, 0, -1, 0}, {0, 1, 0, 0, 0, 0, 0, -1}, {
         0, 1, 0, 0, 0, 0, 0, 1}, {0, 1, 0, 0, 0, 0, 1, 0}, {0, 1, 0, 0, 0, 1,
          0, 0}, {0, 1, 0, 0, 1, 0, 0, 0}, {0, 1, 0, 1, 0, 0, 0, 0}, {0, 1, 1,
          0, 0, 0, 0, 0}, {1, -1, 0, 0, 0, 0, 0, 0}, {1, 0, -1, 0, 0, 0, 0, 
         0}, {1, 0, 0, -1, 0, 0, 0, 0}, {1, 0, 0, 0, -1, 0, 0, 0}, {1, 0, 0, 
         0, 0, -1, 0, 0}, {1, 0, 0, 0, 0, 0, -1, 0}, {1, 0, 0, 0, 0, 0, 
         0, -1}, {1, 0, 0, 0, 0, 0, 0, 1}, {1, 0, 0, 0, 0, 0, 1, 0}, {1, 0, 0,
          0, 0, 1, 0, 0}, {1, 0, 0, 0, 1, 0, 0, 0}, {1, 0, 0, 1, 0, 0, 0, 
         0}, {1, 0, 1, 0, 0, 0, 0, 0}, {1, 1, 0, 0, 0, 0, 0, 0}, {
         1/2, 1/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2}, {
         1/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2}, {
         1/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2}, {
         1/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2}, {
         1/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2}, {
         1/2, 1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2}, {
         1/2, 1/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2}, {
         1/2, 1/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2}, {
         1/2, 1/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2}, {
         1/2, 1/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2}, {
         1/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, (-1)/2}, {
         1/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, 1/2}, {
         1/2, 1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, 1/2}, {
         1/2, 1/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2}, {
         1/2, 1/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, 1/2}, {
         1/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, 1/2, (-1)/2}, {
         1/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, 1/2}, {
         1/2, (-1)/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, 1/2}, {
         1/2, (-1)/2, 1/2, 1/2, (-1)/2, 1/2, 1/2, 1/2}, {
         1/2, (-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, 1/2}, {
         1/2, (-1)/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, 1/2}, {(-1)/2, 1/2, 1/2, 1/
          2, 1/2, 1/2, 1/2, (-1)/2}, {(-1)/2, 1/2, 1/2, 1/2, 1/2, 1/2, (-1)/2,
           1/2}, {(-1)/2, 1/2, 1/2, 1/2, 1/2, (-1)/2, 1/2, 1/2}, {(-1)/2, 1/2,
           1/2, 1/2, (-1)/2, 1/2, 1/2, 1/2}, {(-1)/2, 1/2, 1/2, (-1)/2, 1/2, 
          1/2, 1/2, 1/2}, {(-1)/2, 1/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, 1/
          2}, {(-1)/2, (-1)/2, 1/2, 1/2, 1/2, 1/2, 1/2, 1/2}, {1, 0, 0, 0, 0, 
         0, 0, 0}, {0, 1, 0, 0, 0, 0, 0, 0}, {0, 0, 1, 0, 0, 0, 0, 0}, {0, 0, 
         0, 1, 0, 0, 0, 0}, {0, 0, 0, 0, 1, 0, 0, 0}, {0, 0, 0, 0, 0, 1, 0, 
         0}, {0, 0, 0, 0, 0, 0, 1, 0}, {0, 0, 0, 0, 0, 0, 0, 1}, {
         1/2, 1/2, 1/2, 1/2, 1/2, 1/2, 1/2, 1/2}}, 
       Attributes[Underscript] = {NHoldRest}, 
       Pattern[Notebook$$103$553587`flavorPattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`fl]] := Flatten[{
          Overscript[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`prt}], 
       Pattern[Notebook$$103$553587`antiWhitePattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`w]] := Notebook$$103$553587`pAnti[
         Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`y, 
          Blank[]]], Pattern[Notebook$$103$553587`antiRedPattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`r]] := Notebook$$103$553587`pAnti[
         Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`bg, 
          Blank[]]], Pattern[Notebook$$103$553587`antiGreenPattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`g]] := Notebook$$103$553587`pAnti[
         Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`rb, 
          Blank[]]], Pattern[Notebook$$103$553587`antiBluePattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`b]] := Notebook$$103$553587`pAnti[
         Underoverscript[Notebook$$103$553587`prt, Notebook$$103$553587`rg, 
          Blank[]]], Pattern[Notebook$$103$553587`antiExPattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], "\" \""]] := Notebook$$103$553587`pAnti[
         Overscript[Notebook$$103$553587`prt, 
          Blank[]]], Pattern[Notebook$$103$553587`flavorPattern, 
         Underscript[
          Pattern[Notebook$$103$553587`prt, 
           Blank[]], 
          
          InterpolatingFunction[{{278.15, 463.15}}, {
           5, 7, 0, {38}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
            False}, CompressedData["
1:eJwtzUsNhDAYReFSCTiABQKqgCABCU2YLeENM6yQMBIqoRKQgAQkVAGP/9zk
5luexNZlpZVS0f3s/ueZbfJXj7oVS3QYsOjEP55oenHDA9NBbHHHeBQtetQT
fXQYsJjp44lmoY8Hpl/6uGP8o48e9UofHYY1vwAxjnrh
           "], {
           Developer`PackedArrayForm, {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
            12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
            28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38}, CompressedData["
1:eJwBPQHC/iFib1JlAQAAACYAAAAAAAAAAADwPxet1MHRAPA/AxFNiEcD8D/E
7l+d+QbwPyU17rbpC/A/R11EWbAR8D9xB+NQTxjwP8/LDLDIH/A/aOYov4ko
8D8cA6u9vzHwP0xmx4AoOvA/R9s6EtZG8D8VvJyCl1PwP+j9Y5kjXPA/kAZp
kAZp8D/u6pvk/XXwP+U0X6tnh/A/b6z+QI+U8D8dCo3Xy6HwP3VcDfmSs/A/
KC6yRIDF8D99Qj+TC9PwPxT32tI85fA/ZwsKlZX38D+j/g5bFgrxPx2RYqi/
HPE/Z+6/ApIv8T+CCoN9U0fxPxczNCqEWvE//TTDpt9t8T+zmM5iOovxP+M3
7pz8o/E/vVHQGwW98T/2okUMVdbxPzoZyD7J6vE/6swWF9AJ8j+JtJGt/SPy
Pzwk85DMQ/I/D12ZTQ==
            "]}, {Automatic}]]] := Flatten[{
          Overscript[Notebook$$103$553587`prt, 
           Blank[]], Notebook$$103$553587`prt}], Notebook$$103$553587`fl = 
       InterpolatingFunction[{{278.15, 463.15}}, {
         5, 7, 0, {38}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
          False}, CompressedData["
1:eJwtzUsNhDAYReFSCTiABQKqgCABCU2YLeENM6yQMBIqoRKQgAQkVAGP/9zk
5luexNZlpZVS0f3s/ueZbfJXj7oVS3QYsOjEP55oenHDA9NBbHHHeBQtetQT
fXQYsJjp44lmoY8Hpl/6uGP8o48e9UofHYY1vwAxjnrh
         "], {
         Developer`PackedArrayForm, {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
           13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29,
           30, 31, 32, 33, 34, 35, 36, 37, 38}, CompressedData["
1:eJwBPQHC/iFib1JlAQAAACYAAAAAAAAAAADwPxet1MHRAPA/AxFNiEcD8D/E
7l+d+QbwPyU17rbpC/A/R11EWbAR8D9xB+NQTxjwP8/LDLDIH/A/aOYov4ko
8D8cA6u9vzHwP0xmx4AoOvA/R9s6EtZG8D8VvJyCl1PwP+j9Y5kjXPA/kAZp
kAZp8D/u6pvk/XXwP+U0X6tnh/A/b6z+QI+U8D8dCo3Xy6HwP3VcDfmSs/A/
KC6yRIDF8D99Qj+TC9PwPxT32tI85fA/ZwsKlZX38D+j/g5bFgrxPx2RYqi/
HPE/Z+6/ApIv8T+CCoN9U0fxPxczNCqEWvE//TTDpt9t8T+zmM5iOovxP+M3
7pz8o/E/vVHQGwW98T/2okUMVdbxPzoZyD7J6vE/6swWF9AJ8j+JtJGt/SPy
Pzwk85DMQ/I/D12ZTQ==
          "]}, {Automatic}], Notebook$$103$553587`pAnti[
         Pattern[Notebook$$103$553587`p, 
          Blank[]]] := 
       Notebook$$103$553587`position[
        Notebook$$103$553587`e8Orig, -Part[Notebook$$103$553587`e8Orig, 
           Min[Notebook$$103$553587`p, 256]]], 
       Notebook$$103$553587`flavorList = {{{
          Notebook$$103$553587`e, Notebook$$103$553587`\[Mu], 
           Notebook$$103$553587`\[Tau]}, {
           Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`e], 
           Subscript[Notebook$$103$553587`\[Nu], Notebook$$103$553587`\[Mu]], 
           Subscript[
           Notebook$$103$553587`\[Nu], Notebook$$103$553587`\[Tau]]}}, {{
          Notebook$$103$553587`d, Notebook$$103$553587`s, 
           Notebook$$103$553587`b}, {
          Notebook$$103$553587`u, Notebook$$103$553587`c, 
           Notebook$$103$553587`t}}, {{
           Superscript[Notebook$$103$553587`g, 
            Row[{Notebook$$103$553587`g, 
              Overscript[Notebook$$103$553587`b, 
               Blank[]]}]], 
           Superscript[Notebook$$103$553587`g, 
            Row[{Notebook$$103$553587`r, 
              Overscript[Notebook$$103$553587`b, 
               Blank[]]}]], 
           Superscript[Notebook$$103$553587`g, 
            Row[{Notebook$$103$553587`r, 
              Overscript[Notebook$$103$553587`g, 
               Blank[]]}]]}, {
           Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`L], 
           Subscript[Notebook$$103$553587`\[Omega], Notebook$$103$553587`R], 
           Notebook$$103$553587`W}}, {{
           Row[{
             Subscript[Notebook$$103$553587`x, 1], 
             Notebook$$103$553587`\[CapitalPhi]}], 
           Row[{
             Subscript[Notebook$$103$553587`x, 2], 
             Notebook$$103$553587`\[CapitalPhi]}], 
           Row[{
             Subscript[Notebook$$103$553587`x, 3], 
             Notebook$$103$553587`\[CapitalPhi]}]}, {
           Row[{
             Subscript[Notebook$$103$553587`e, Notebook$$103$553587`S], 
             Notebook$$103$553587`\[Phi]}], 
           Row[{
             Subscript[Notebook$$103$553587`e, Notebook$$103$553587`T], 
             Notebook$$103$553587`\[Phi]}], Notebook$$103$553587`B}}, {{
           Subscript[Notebook$$103$553587`Ex, 1]}, {
           Subscript[Notebook$$103$553587`Ex, 2]}}}, 
       Notebook$$103$553587`flavorListStr = {{{"e", "\[Mu]", "\[Tau]"}, {
           Subscript["\[Nu]", "e"], 
           Subscript["\[Nu]", "\[Mu]"], 
           Subscript["\[Nu]", "\[Tau]"]}}, {{"d", "s", "b"}, {
          "u", "c", "t"}}, {{
           Superscript["g", 
            Row[{"g", 
              Overscript["b", "_"]}]], 
           Superscript["g", 
            Row[{"r", 
              Overscript["b", "_"]}]], 
           Superscript["g", 
            Row[{"r", 
              Overscript["g", "_"]}]]}, {
           Subscript["\[Omega]", "L"], 
           Subscript["\[Omega]", "R"], "W"}}, {{
           Row[{
             Subscript["x", "1"], "\[CapitalPhi]"}], 
           Row[{
             Subscript["x", "2"], "\[CapitalPhi]"}], 
           Row[{
             Subscript["x", "3"], "\[CapitalPhi]"}]}, {
           Row[{
             Subscript["e", "S"], "\[CapitalPhi]"}], 
           Row[{
             Subscript["e", "T"], "\[CapitalPhi]"}], "B"}}, {{
           Subscript["Ex", "1"]}, {
           Subscript["Ex", "2"]}}}, 
       Notebook$$103$553587`qConvDoNoAnti = {
        "BottomQuark" -> "b", "BottomQuarkBar" -> "b", "CharmQuark" -> "c", 
         "CharmQuarkBar" -> "c", "DownQuark" -> "d", "DownQuarkBar" -> "d", 
         "StrangeQuark" -> "s", "StrangeQuarkBar" -> "s", "TopQuark" -> "t", 
         "TopQuarkBar" -> "t", "UpQuark" -> "u", "UpQuarkBar" -> "u"}, 
       Notebook$$103$553587`colorListExp = {
        Notebook$$103$553587`y, Notebook$$103$553587`o, 
         Notebook$$103$553587`c, Notebook$$103$553587`m, 
         Notebook$$103$553587`w, Notebook$$103$553587`r, 
         Notebook$$103$553587`g, Notebook$$103$553587`b, 
         Notebook$$103$553587`e, Notebook$$103$553587`k}, 
       Notebook$$103$553587`colorList = {
        "y", "o", "c", "m", "w", "r", "g", "b", "e", "k"}, 
       Notebook$$103$553587`spList = {
         Overscript["L", "\[Vee]"], 
         Overscript["R", "\[Wedge]"], 
         Overscript["L", "\[Wedge]"], 
         Overscript["R", "\[Vee]"]}, 
       Attributes[Subsuperscript] = {NHoldRest, ReadProtected}, 
       Notebook$$103$553587`tri[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := 
       Notebook$$103$553587`polyTri[
        Notebook$$103$553587`coords, Notebook$$103$553587`scale, Subtract, 
         "Tetrahedron", Notebook$$103$553587`plDims], 
       Notebook$$103$553587`polyTri[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`pm, 
          Blank[]], 
         Pattern[Notebook$$103$553587`shape, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := If[Notebook$$103$553587`plDims == 3, 
         Translate[
          Scale[{
            PolyhedronData[Notebook$$103$553587`shape, "Faces"]}, {1, 1, 1} 
           Notebook$$103$553587`scale, {0, 0, 0}], 
          Notebook$$103$553587`coords], 
         Polygon[{{
           Part[Notebook$$103$553587`coords, 1] - Notebook$$103$553587`scale, 
            Notebook$$103$553587`pm[
             Part[Notebook$$103$553587`coords, 2], Notebook$$103$553587`scale/
             Sqrt[3]]}, {
           Part[Notebook$$103$553587`coords, 1] + Notebook$$103$553587`scale, 
            Notebook$$103$553587`pm[
             Part[Notebook$$103$553587`coords, 2], Notebook$$103$553587`scale/
             Sqrt[3]]}, {
            Part[Notebook$$103$553587`coords, 1], 
            Notebook$$103$553587`pm[
             Part[
             Notebook$$103$553587`coords, 2], (-2) (
              Notebook$$103$553587`scale/Sqrt[3])]}}]], 
       Notebook$$103$553587`pm[
         Pattern[Notebook$$103$553587`n, 
          Blank[]]] := Flatten[
         Outer[List, 
          Apply[Sequence, 
           Table[{-1, 1}, {Notebook$$103$553587`n}]]], Notebook$$103$553587`n - 
         1], Notebook$$103$553587`inv[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := If[Notebook$$103$553587`plDims == 3, 
         Translate[
          Scale[{
            PolyhedronData["Dodecahedron", "Faces"]}, {1, 1, 1} (
            Notebook$$103$553587`scale/2), {0, 0, 0}], 
          Notebook$$103$553587`coords], 
         Notebook$$103$553587`poly2D[
         5, Notebook$$103$553587`coords, Notebook$$103$553587`scale]], 
       Notebook$$103$553587`poly2D[
         Pattern[Notebook$$103$553587`sides$, 
          Blank[]], 
         Pattern[Notebook$$103$553587`coords$, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale$, 
          Blank[]]] := Polygon[
         Table[{
          Part[Notebook$$103$553587`coords$, 1] + 
           Notebook$$103$553587`scale$ 
            Cos[(2 FE`Pi$$785) (Notebook$$103$553587`i/
               Notebook$$103$553587`sides$)], 
           Part[Notebook$$103$553587`coords$, 2] + 
           Notebook$$103$553587`scale$ 
            Sin[(2 FE`Pi$$785) (Notebook$$103$553587`i/
               Notebook$$103$553587`sides$)]}, {
          Notebook$$103$553587`i, (-1)/2, Notebook$$103$553587`sides$ - 1/
           2}]], Attributes[Notebook$$103$553587`sides$] = {Temporary}, 
       Attributes[Notebook$$103$553587`coords$] = {Temporary}, 
       Attributes[Notebook$$103$553587`scale$] = {Temporary}, FE`Pi$$785 = 1, 
       Notebook$$103$553587`utr[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := 
       Notebook$$103$553587`polyTri[
        Notebook$$103$553587`coords, Notebook$$103$553587`scale, Plus, 
         "Icosahedron", Notebook$$103$553587`plDims], Notebook$$103$553587`dia[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := If[Notebook$$103$553587`plDims == 3, 
         Translate[
          Scale[{
            PolyhedronData["Octahedron", "Faces"]}, {1, 1, 1} 
           Notebook$$103$553587`scale, {0, 0, 0}], 
          Notebook$$103$553587`coords], 
         Polygon[{{
           Part[Notebook$$103$553587`coords, 1] - Notebook$$103$553587`scale, 
            Part[Notebook$$103$553587`coords, 2]}, {
            Part[Notebook$$103$553587`coords, 1], 
            Part[Notebook$$103$553587`coords, 2] + 
            Notebook$$103$553587`scale Sqrt[2]}, {
           Part[Notebook$$103$553587`coords, 1] + Notebook$$103$553587`scale, 
            Part[Notebook$$103$553587`coords, 2]}, {
            Part[Notebook$$103$553587`coords, 1], 
            Part[Notebook$$103$553587`coords, 2] - Notebook$$103$553587`scale 
            Sqrt[3]}}]], Notebook$$103$553587`squ[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := If[Notebook$$103$553587`plDims == 3, 
         Translate[
          Scale[{
            PolyhedronData["Cube", "Faces"]}, {1, 1, 1} 
           Notebook$$103$553587`scale, {0, 0, 0}], 
          Notebook$$103$553587`coords], 
         Notebook$$103$553587`poly2D[
         4, Notebook$$103$553587`coords, Notebook$$103$553587`scale]], 
       Notebook$$103$553587`cir[
         Pattern[Notebook$$103$553587`coords, 
          Blank[]], 
         Pattern[Notebook$$103$553587`scale, 
          Blank[]], 
         Pattern[Notebook$$103$553587`plDims, 
          Blank[]]] := If[Notebook$$103$553587`plDims == 3, 
         Sphere[Notebook$$103$553587`coords, Notebook$$103$553587`scale], 
         Disk[
          Part[Notebook$$103$553587`coords, 
           Span[1, 2]], Notebook$$103$553587`scale]], 
       Notebook$$103$553587`sets = 0, $CellContext`var2[
         Pattern[$CellContext`c1, 
          Blank[]], 
         Pattern[$CellContext`c2, 
          Blank[]]] := Style[
         Subscript[$CellContext`c1, $CellContext`c2], 12, 
         Italic], $CellContext`var4[
         Pattern[$CellContext`c1, 
          Blank[]]] := Style[$CellContext`c1, 12, Italic], 
       Attributes[PlotRange] = {ReadProtected}}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 234, 7, 230, "Title"],
Cell[1723, 44, 1489, 23, 302, "Text"],
Cell[3215, 69, 203715, 4424, 535, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Hup4ehLaGJD3KBgQyO@BKh@d *)
